
;**************************************************************************
;*                      Keep the Power Bank active                        *
;**************************************************************************
;*          v 1.04 - 05.01.2019                                           *
;**************************************************************************
;*          Hardw.: PIC10F202 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:  PowerBank     *
;**************************************************************************



;==========================================================================
;
;       Register Definitions
;
;==========================================================================

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files -----------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
OSCCAL                       EQU     H'0005'
GPIO                         EQU     H'0006'


;----- STATUS Bits --------------------------------------------------------

GPWUF                        EQU     H'0007'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;----- OPTION Bits --------------------------------------------------------

NOT_GPWU                     EQU     H'0007'
NOT_GPPU                     EQU     H'0006'
T0CS                         EQU     H'0005'
T0SE                         EQU     H'0004'
PSA                          EQU     H'0003'
PS2                          EQU     H'0002'
PS1                          EQU     H'0001'
PS0                          EQU     H'0000'

;----- OSCCAL Bits --------------------------------------------------------

CAL6                         EQU     H'0007'
CAL5                         EQU     H'0006'
CAL4                         EQU     H'0005'
CAL3                         EQU     H'0004'
CAL2                         EQU     H'0003'
CAL1                         EQU     H'0002'
CAL0			     EQU     H'0001'
FOSC4			     EQU     H'0000'



;==========================================================================
;
;       RAM Definition
;
;==========================================================================

        __MAXRAM H'1F'
	__BADRAM H'07'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_MCLRE_ON                    EQU     H'0FFF'
_MCLRE_OFF                   EQU     H'0FEF'
_CP_ON                       EQU     H'0FF7'
_CP_OFF                      EQU     H'0FFF'
_WDT_ON                      EQU     H'0FFF'
_WDT_OFF                     EQU     H'0FFB'
_IntRC_OSC                   EQU     H'0FFF'



;	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT

_U001			     EQU     B'000000001000'		;MCLR disabled

	__CONFIG        _U001

;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'08'		;Used in delay routine
TIMER2		EQU	H'09'		; "	"	"	

tt1		EQU	H'0A'
tt2		EQU	H'0B'
tt3		EQU	H'0C'

fnc1		EQU	H'0D'		;standard run / switch off
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		nop
;
		MOVLW	B'10010111'	;Set PIC options (See datasheet Pg.22).
		option			;Write the OPTION register.
;
;		clrf	OSCCAL		;not needed - after reset value is 1111 1110
;
		MOVLW	B'11111000'
		tris	GPIO


; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		movlw	B'11111111'
		movwf	GPIO

main_loop	movlw	B'00000000'
		movwf	GPIO
		call	dr_on

		movlw	B'11111111'
		movwf	GPIO
		btfsc	GPIO,D'003'
		call	dr_off_long
		btfss	GPIO,D'003'
		call	dr_off_short

		goto	main_loop
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------------------

;		*********************************************
;		*               delay routine               *
;		*********************************************

;----------------------------------------------------------------------------
dr5		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1
		retlw	0
;----------------------------------------------------------------------------
dr1		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1b	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2b	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2b
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1b
		retlw	0
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
dr_on		call	dr5
		call	dr5
		call	dr5
		call	dr5
		retlw	0
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
dr_off_short	call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		retlw	0
;----------------------------------------------------------------------------
dr_off_long	call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		call	dr1
		retlw	0
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


		END